@@ -31,10 +31,9 @@ module.exports = function (nylon_path) {
         async.each(modelues, function (modelue, next) {
             
             try {
-                require(nylon_path + "/lib/modules/" + modelue)(function(){
-                    logger.info("Load Module   :: " + modelue +" Complete!");
-                    next();
-                },app,db, nylon_path);
+                logger.info("Load Module   :: " + modelue + " Complete!");
+                require(nylon_path + "/lib/modules/" + modelue)(app, db, nylon_path);
+                next();
             } catch (err) {
                 logger.error(err);
                 next(err);
