@@ -14,7 +14,7 @@ var logger = require('winston');
 var RDBStore = require('./../datasource/rethinkdb-session')(session);
 
 
-module.exports = function (callback, app, db) {
+module.exports = function ( app, db) {
 
 
     var rdbStore = new RDBStore({
@@ -49,6 +49,6 @@ module.exports = function (callback, app, db) {
         next();
     });
 
-    callback();
+    //callback();
 
 }
\ No newline at end of file
