@@ -6,13 +6,13 @@ var push_list = [];
 
 const config = require(process.cwd() + '/config/config');
 
-module.exports = function (callback,app) {
-    if (config.h2.enable) {
+module.exports = function (app) {
+    if (config.h2) {
         if (config.h2.pusher == "auto") {
 
             fs.readFile(work_dir + '/public/pusher.cache.json', function (err, content) {
                 if (err) content = "[]";
-                //push_list = JSON.parse(content);
+                push_list = JSON.parse(content);
             });
         } else if (config.h2.pusher == "on") {
             fs.readFile(work_dir + '/public/pusher.json', function (err, content) {
@@ -21,6 +21,7 @@ module.exports = function (callback,app) {
             });
         }
     }
+
     app.use(function (req, res, next_func) {
         if (config.h2.enable) {
             if (config.h2.pusher == "auto" || config.h2.pusher == "on") {
@@ -31,9 +32,11 @@ module.exports = function (callback,app) {
                     url.indexOf('/manifest.json') == 0 ||
                     url.indexOf('/bower_components/') == 0 ||
                     url.indexOf('/css/') == 0 ||
-                    url.indexOf('/images/') == 0 ||
-                    url.indexOf('/src/') == 0 ||
-                    url.indexOf('/js/') == 0) {
+                    url.indexOf('/images/') == 0||
+                    url.indexOf('/js/') == 0){
+                    // ||
+                   // url.indexOf('/src/') == 0 ||
+                   // url.indexOf('/js/') == 0) {
                     if (!push_list.includes(url)) {
                         push_list.push(url);
                         fs.writeFile(work_dir + "/public/pusher.cache.json", JSON.stringify(push_list), function (err) {
@@ -92,7 +95,7 @@ module.exports = function (callback,app) {
                                         }
                                     },
                                     function (err, stream) {
-                                        if (err) next(err);
+                                        if (err) next();
                                         // console.log(content);
                                         stream.end(content);
                                         next();
@@ -100,7 +103,7 @@ module.exports = function (callback,app) {
                                 );
                             });
                         } catch (err) {
-                            next(err);
+                            next();
                         }
                     }, function (err) {
                         callback(err);
@@ -112,5 +115,5 @@ module.exports = function (callback,app) {
 
         next_func();
     });
-    callback();
+
 }
\ No newline at end of file
