@@ -51,14 +51,18 @@ var loadRouter = function (app, routes, callback) {
 
 }
 
-module.exports = function (callback, app, db, nylon_path) {
-    app = require('./../routes/oauth.routes')(app,nylon_path);
+module.exports = function (app, db, nylon_path) {
+    app = require('./../routes/oauth.routes')(app, nylon_path);
+    //app = require('./../routes/pusher.routes')(app);
+
     fscan.scan(work_dir + route_dir, ".routes.js", true, function (err, routes) {
         loadRouter(app, routes, function (err, app) {
 
+
             if (config.h2.enable) {
                 if (config.h2.pusher == "auto" || config.h2.pusher == "on") {
                     require('./../routes/pusher.routes')(app);
+
                 }
             }
 
@@ -66,10 +70,12 @@ module.exports = function (callback, app, db, nylon_path) {
 
             app.use('/nylon', express.static(nylon_path + '/lib/public'));
 
+
+
             app.use(function (req, res, next) {
                 var ref = req.headers["referer"];
                 var url = URL.parse(req.url, true).pathname;
-                if (url.indexOf('api') < 0 && url.indexOf('.') < 0) {
+                if (url.indexOf('api') < 0 && url.indexOf('.') < 0 && url.indexOf('pusher') < 0) {
                     res.status(200);
                     if (config.h2.enable) {
                         if (config.h2.pusher == "auto") {
@@ -89,7 +95,7 @@ module.exports = function (callback, app, db, nylon_path) {
                     if (ref) {
                         next();
                     } else {
-                        if (url.indexOf('api') < 0) {
+                        if (url.indexOf('api') < 0 && url.indexOf('pusher') < 0) {
                             if (config.h2.enable) {
                                 if (config.h2.pusher == "auto") {
                                     res.pusher(false, function (err) {
@@ -111,7 +117,9 @@ module.exports = function (callback, app, db, nylon_path) {
 
                 }
             });
-            callback();
+
+
+
         });
     });
 }
\ No newline at end of file
