@@ -20,7 +20,7 @@ function getApp(appid, appkey, r, callback) {
 
 }
 
-exports.js = function (req, res,nylon_path) {
+exports.js = function (req, res, nylon_path) {
     var r = req.r;
     var appid = req.params.appid;
     var appkey = req.params.appkey;
@@ -28,7 +28,7 @@ exports.js = function (req, res,nylon_path) {
         if (data.error) {
             res.send(data);
         } else {
-            fs.readFile(nylon_path+'/lib/public/js/oauth.js', "utf-8", function (err, content) {
+            fs.readFile(nylon_path + '/lib/public/js/oauth.js', "utf-8", function (err, content) {
                 if (err) return console.log(err);
                 content = content.replace(/{OAUTH_HOST}/g, req.headers.host);
                 content = content.replace(/{OAUTH_APP_CALLBACK}/g, data.allow_callback_url);
@@ -46,7 +46,7 @@ exports.js = function (req, res,nylon_path) {
 exports.register = function (req, res) {
     var pid = req.body.pid;
     if (pid) {
-   console.log("bef sid : "+req.sessionID);
+        console.log("bef sid : " + req.sessionID);
         r.db("oauth").table("users").filter({ pid: pid })
             .run()
             .then(function (ou) {
@@ -65,8 +65,8 @@ exports.register = function (req, res) {
                                     r.db("oauth").table("users").get(ou[0].id).update(ou[0]).run().then(function (rdd) {
                                         r.db("oauth").table("users").get(cu.id).delete().run().then(function (xxr) {
                                             req.login(ou[0], function (err) {
-                                                console.log("after sid : "+req.sessionID);
-                                                req.user.id=ou[0].id;
+                                                console.log("after sid : " + req.sessionID);
+                                                req.user.id = ou[0].id;
                                                 res.redirect('/oauth/logined');
                                             });
                                         });
@@ -133,7 +133,7 @@ exports.login = function (req, res) {
 
 exports.logined = function (req, res) {
     var r = req.r;
-     console.log("logined sid : "+req.sessionID);
+    console.log("logined sid : " + req.sessionID);
     r.db("oauth").table("session")
         .get(req.sessionID)
         .run()
@@ -164,10 +164,10 @@ exports.logined = function (req, res) {
                         register: u.register
                     };
                     var token = jwt.sign(session, config.oauth.jwt.clientSecret, { expiresIn: config.oauth.jwt.timeout });
-                     if (!u.register) {
+                    if (!u.register) {
                         res.render("register", {});
-                        return ;
-                     }
+                        return;
+                    }
 
                     r.db("oauth").table("session_ref")
                         .get(req.sessionID)
@@ -178,7 +178,7 @@ exports.logined = function (req, res) {
                                 .delete()
                                 .run()
                                 .then(function (d) {
-         
+
                                     if (!u.status) {
                                         res.render("appUser", {
                                             message: "สถานะของคุณถูกปิดใช้งาน",
@@ -188,7 +188,7 @@ exports.logined = function (req, res) {
                                             appName: "-",
                                             appStatus: "-",
                                             appRole: "-",
-                                            link: config.host+"/my-app?token=" + token,
+                                            link: config.host + "/my-app?token=" + token,
                                             messageLink: "กรุณาติดต่อผู้ดูแลระบบ"
                                         })
 
@@ -222,7 +222,7 @@ exports.logined = function (req, res) {
                                                         appName: app_name,
                                                         appStatus: check_app_status,
                                                         appRole: app_role,
-                                                        link: config.host+"/my-app?token=" + token,
+                                                        link: config.host + "/my-app?token=" + token,
                                                         messageLink: "ไปยังหน้าระบบที่ใช้งานได้ของคุณ"
                                                     })
                                                 }
@@ -236,7 +236,7 @@ exports.logined = function (req, res) {
                                                     appName: data.appname,
                                                     appStatus: "-",
                                                     appRole: "-",
-                                                    link: config.host+"/my-app?token=" + token,
+                                                    link: config.host + "/my-app?token=" + token,
                                                     messageLink: "ไปยังหน้าลงทะเบียนระบบ"
                                                 })
 
@@ -285,11 +285,13 @@ exports.userInfo = function (req, res) {
     if (req.user) {
         var session = {
             id: req.user.id,
-            name: req.user.id,
+            name: req.user.name,
             photo: req.user.photo,
             email: req.user.email,
             gender: req.user.gender,
-            role: req.user.role
+            role: req.user.role,
+            status: req.user.status,
+            apps: req.user.apps
         };
         var token = jwt.sign(session, config.oauth.jwt.clientSecret, { expiresIn: config.oauth.jwt.timeout });
 
