@@ -22,12 +22,28 @@ module.exports = function (app) {
 
                 });
             });
-        } else if (config.h2.pusher == "on") {
-            app.get('/pusher', function (req, res, next) {
-                res.pusher(false, function (err) {
-                    res.end("");
+        } else
+            if (config.h2.pusher == "on" || config.h2.pusher == "auto") {
+                app.get('/pusher', function (req, res, next) {
+                    try {
+                        //fs.readFile(work_dir + '/public/pusher.json', function (err, content) {
+                           // if (err) content = "[]";
+                           // var push_list = JSON.parse(content);
+                           // console.log(push_list);
+                            res.pusher(false, function (err) {
+                                res.end("");
+                            });
+                       //});
+                    } catch (e) {
+
+                        console.log(e);
+                    }
+
+
                 });
-            });
-        }
+
+             //   return app;
+
+            }
     }
 }
\ No newline at end of file
